Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_, and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

The changes listed in this file are categorised as follows:

    - Added: new features
    - Changed: changes in existing functionality
    - Deprecated: soon-to-be removed features
    - Removed: now removed features
    - Fixed: any bug fixes
    - Security: in case of vulnerabilities.


master
------

v0.1.0 - 2021-03-03
-------------------

- (`#2 <https://github.com/openscm/openscm-zenodo/pull/2>`_) Add basic docs
- (`#1 <https://github.com/openscm/openscm-zenodo/pull/1>`_) Add basic repository setup and functionality
